@@ -8,12 +8,12 @@ package IO::Async::SSL;
 use strict;
 use warnings;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 $VERSION = eval $VERSION;
 
 use Carp;
 
-use IO::Socket::SSL qw( $SSL_ERROR SSL_WANT_READ SSL_WANT_WRITE );
+use IO::Socket::SSL 1.968 qw( $SSL_ERROR SSL_WANT_READ SSL_WANT_WRITE ); # default_ca
 use POSIX qw( EAGAIN EWOULDBLOCK );
 
 use IO::Async::Handle 0.29;
